@@ -33,7 +33,6 @@ import DraftVecUtils
 
 from draftgeoutils.general import geomType, vec
 from draftgeoutils.geometry import get_normal
-from draftgeoutils.wires import isReallyClosed
 from draftgeoutils.intersections import wiresIntersect, connect
 
 # Delay import of module until first use because it is heavy
@@ -238,7 +237,7 @@ def offsetWire(wire, dvec, bind=False, occ=False,
         if norm is None:
             norm = App.Vector(0, 0, 1)
 
-    closed = isReallyClosed(wire)
+    closed = wire.isClosed()
     nedges = []
     if occ:
         length = abs(dvec.Length)
@@ -297,13 +296,14 @@ def offsetWire(wire, dvec, bind=False, occ=False,
         # check against dvec provided for the offset direction
         # would not know if dvec is vector of width (Left/Right Align)
         # or width/2 (Center Align)
-        dvec0 = DraftVecUtils.scaleTo(v0, dvec.Length)
-        if DraftVecUtils.equals(dvec0, dvec):
+        v0.normalize()
+        v1 = App.Vector(dvec).normalize()
+        if v0.isEqual(v1, 0.0001):
             # "Left Offset" (Left Align or 'left offset' in Centre Align)
             firstDir = 1
             firstAlign = 'Left'
             alignListC.append('Left')
-        elif DraftVecUtils.equals(dvec0, dvec.negative()):
+        elif v0.isEqual(v1.negative(), 0.0001):
             # "Right Offset" (Right Align or 'right offset' in Centre Align)
             firstDir = -1
             firstAlign = 'Right'
